@@ -146,7 +146,8 @@ struct param_spec
 typedef enum
 {
 	SQL_simple,
-	SQL_nestedselect
+	SQL_nestedselect,
+        SQL_tablefunction
 }
 sql_table_type;
 
@@ -166,7 +167,12 @@ struct sql_table
 	union
 	{
 		char                 *simple;
-		sql_select_statement *select;
+		sql_select_statement *select;	        
+		struct
+		{
+			gchar *funcname;
+			GList *funcarglist;
+		} function;
 	}
 	d;
 	char          *as;
@@ -182,22 +188,27 @@ typedef enum
 {
 	SQL_eq,
 	SQL_is,
-	SQL_isnot,
 	SQL_in,
 	SQL_like,
-	SQL_notin,
 	SQL_between,
 	SQL_gt,
 	SQL_lt,
 	SQL_geq,
 	SQL_leq,
-	SQL_diff
+	SQL_diff,
+	SQL_regexp,
+	SQL_regexp_ci,
+	SQL_not_regexp,
+	SQL_not_regexp_ci,
+	SQL_similar,
+        SQL_not
 }
 sql_condition_operator;
 
 struct sql_condition
 {
 	sql_condition_operator op;
+	gboolean               negated;
 
 	union
 	{
